@@ -1,3 +1,3 @@
-from .featureimpact import get_averaged_impact
+from .featureimpact import make_averaged_impact
 from .featureimpact import FeatureImpact
 from .featureimpact import FeatureImpactError
