@@ -5,7 +5,7 @@ from scipy.stats.mstats import mquantiles
 import numpy
 
 
-def get_averaged_impact(impact, normalize=False):
+def make_averaged_impact(impact, normalize=False):
     """
     Computes the averaged impact across all events for each feature
 
@@ -21,7 +21,7 @@ def get_averaged_impact(impact, normalize=False):
     for series in imparray.transpose():
         average.append(series.mean())
     average = numpy.array(average, dtype=float)
-    if normalize is True:
+    if normalize:
         average /= average.sum()
     return average
 
@@ -85,7 +85,7 @@ class FeatureImpact(object):
         if self._quantiles is None:
             raise FeatureImpactError("make_quantiles() must be called first "
                                      "or the quantiles explicitly assigned")
-        if hasattr(estimator, 'predict') is False:
+        if not hasattr(estimator, 'predict'):
             raise FeatureImpactError("estimator does not implement predict()")
         X_ref = numpy.array(X, dtype=float)
         y_ref = self._evaluate(estimator, X_ref)
@@ -97,7 +97,7 @@ class FeatureImpact(object):
                 result_event.append(impact)
             result.append(result_event)
         result = numpy.array(result, dtype=float)
-        if normalize is True:
+        if normalize:
             result /= result.sum(axis=1)[:, numpy.newaxis]
         return result
 
